==> zio-aws-lightsail_2.12-5.17.206.1-sources.jar: zio/aws/lightsail/model/GetLoadBalancerTlsCertificatesResponse.scala <==
package zio.aws.lightsail.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GetLoadBalancerTlsCertificatesResponse(
    tlsCertificates: Optional[
      Iterable[zio.aws.lightsail.model.LoadBalancerTlsCertificate]
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lightsail.model.GetLoadBalancerTlsCertificatesResponse = {
    import GetLoadBalancerTlsCertificatesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lightsail.model.GetLoadBalancerTlsCertificatesResponse
      .builder()
      .optionallyWith(
        tlsCertificates.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tlsCertificates)
      .build()
  }
  def asReadOnly
      : zio.aws.lightsail.model.GetLoadBalancerTlsCertificatesResponse.ReadOnly =
    zio.aws.lightsail.model.GetLoadBalancerTlsCertificatesResponse
      .wrap(buildAwsValue())
}
object GetLoadBalancerTlsCertificatesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lightsail.model.GetLoadBalancerTlsCertificatesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.lightsail.model.GetLoadBalancerTlsCertificatesResponse =
      zio.aws.lightsail.model.GetLoadBalancerTlsCertificatesResponse(
        tlsCertificates.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def tlsCertificates: Optional[
      List[zio.aws.lightsail.model.LoadBalancerTlsCertificate.ReadOnly]
    ]
    def getTlsCertificates: ZIO[Any, AwsError, List[
      zio.aws.lightsail.model.LoadBalancerTlsCertificate.ReadOnly
    ]] = AwsError.unwrapOptionField("tlsCertificates", tlsCertificates)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lightsail.model.GetLoadBalancerTlsCertificatesResponse
  ) extends zio.aws.lightsail.model.GetLoadBalancerTlsCertificatesResponse.ReadOnly {
    override val tlsCertificates: Optional[
      List[zio.aws.lightsail.model.LoadBalancerTlsCertificate.ReadOnly]
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.tlsCertificates())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.lightsail.model.LoadBalancerTlsCertificate.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.lightsail.model.GetLoadBalancerTlsCertificatesResponse
  ): zio.aws.lightsail.model.GetLoadBalancerTlsCertificatesResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-lightsail_2.13-5.17.104.4-sources.jar: zio/aws/lightsail/model/GetLoadBalancerTlsCertificatesResponse.scala <==
package zio.aws.lightsail.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class GetLoadBalancerTlsCertificatesResponse(
    tlsCertificates: Option[
      Iterable[zio.aws.lightsail.model.LoadBalancerTlsCertificate]
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lightsail.model.GetLoadBalancerTlsCertificatesResponse = {
    import GetLoadBalancerTlsCertificatesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lightsail.model.GetLoadBalancerTlsCertificatesResponse
      .builder()
      .optionallyWith(
        tlsCertificates.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tlsCertificates)
      .build()
  }
  def asReadOnly
      : zio.aws.lightsail.model.GetLoadBalancerTlsCertificatesResponse.ReadOnly =
    zio.aws.lightsail.model.GetLoadBalancerTlsCertificatesResponse
      .wrap(buildAwsValue())
}
object GetLoadBalancerTlsCertificatesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lightsail.model.GetLoadBalancerTlsCertificatesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.lightsail.model.GetLoadBalancerTlsCertificatesResponse =
      zio.aws.lightsail.model.GetLoadBalancerTlsCertificatesResponse(
        tlsCertificates.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def tlsCertificates: Option[
      List[zio.aws.lightsail.model.LoadBalancerTlsCertificate.ReadOnly]
    ]
    def getTlsCertificates: ZIO[Any, AwsError, List[
      zio.aws.lightsail.model.LoadBalancerTlsCertificate.ReadOnly
    ]] = AwsError.unwrapOptionField("tlsCertificates", tlsCertificates)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lightsail.model.GetLoadBalancerTlsCertificatesResponse
  ) extends zio.aws.lightsail.model.GetLoadBalancerTlsCertificatesResponse.ReadOnly {
    override val tlsCertificates: Option[
      List[zio.aws.lightsail.model.LoadBalancerTlsCertificate.ReadOnly]
    ] = scala
      .Option(impl.tlsCertificates())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.lightsail.model.LoadBalancerTlsCertificate.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.lightsail.model.GetLoadBalancerTlsCertificatesResponse
  ): zio.aws.lightsail.model.GetLoadBalancerTlsCertificatesResponse.ReadOnly =
    new Wrapper(impl)
}
